import * as interfaces from './interfaces.js';
import { XInvoice } from './classes.xinvoice.js';

// Import format-specific encoder/decoder classes
import { FacturXEncoder } from './formats/facturx.encoder.js';
import { FacturXDecoder } from './formats/facturx.decoder.js';
import { XInvoiceEncoder } from './formats/xinvoice.encoder.js';
import { XInvoiceDecoder } from './formats/xinvoice.decoder.js';
import { DecoderFactory } from './formats/decoder.factory.js';
import { BaseDecoder } from './formats/base.decoder.js';

// Export interfaces
export { interfaces };

// Export main class
export { XInvoice };

// Export format classes
export { 
  // Base classes
  BaseDecoder,
  DecoderFactory,
  
  // Format-specific encoders
  FacturXEncoder,
  XInvoiceEncoder,
  
  // Format-specific decoders
  FacturXDecoder, 
  XInvoiceDecoder
};

// For backward compatibility
export { FacturXEncoder as ZugferdXmlEncoder };
export { FacturXDecoder as ZUGFeRDXmlDecoder };